habitat.uploader
================

.. automodule:: habitat.uploader

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Extractor
      ExtractorManager
      UKHASExtractor
      Uploader
      UploaderThread
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
   
      CollisionError
      UnmergeableError
   
   